@@ -1,4 +1,4 @@
-from volworld_common.util.id_util import new_rand_test_user_name, rand_test_id
+from volworld_common.util.id_util import new_rand_test_user_name, rand_uuid
 from volworld_common.test.behave.BehaveUtil import BehaveUtil
 
 class UserInfo:
@@ -8,7 +8,7 @@ class UserInfo:
         # for testing wrong formatted username, put the name before generated id
         self.used_name = f"{self.name}xxxxxx{new_rand_test_user_name()}"
         self.password = password
-        self.user_id = rand_test_id()
+        self.user_id = rand_uuid()
 
 
 class UserPool:
